==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/netapp/kotlin/outputs/WeeklyScheduleResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.netapp.kotlin.outputs

import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 * Weekly Schedule properties, make a snapshot every week at a specific day or days
 * @property day Indicates which weekdays snapshot should be taken, accepts a comma separated list of week day names in english
 * @property hour Indicates which hour in UTC timezone a snapshot should be taken
 * @property minute Indicates which minute snapshot should be taken
 * @property snapshotsToKeep Weekly snapshot count to keep
 * @property usedBytes Resource size in bytes, current storage usage for the volume in bytes
 */
public data class WeeklyScheduleResponse(
    public val day: String? = null,
    public val hour: Int? = null,
    public val minute: Int? = null,
    public val snapshotsToKeep: Int? = null,
    public val usedBytes: Double? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.netapp.outputs.WeeklyScheduleResponse):
            WeeklyScheduleResponse = WeeklyScheduleResponse(
            day = javaType.day().map({ args0 -> args0 }).orElse(null),
            hour = javaType.hour().map({ args0 -> args0 }).orElse(null),
            minute = javaType.minute().map({ args0 -> args0 }).orElse(null),
            snapshotsToKeep = javaType.snapshotsToKeep().map({ args0 -> args0 }).orElse(null),
            usedBytes = javaType.usedBytes().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/netapp/kotlin/outputs/WeeklyScheduleResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.netapp.kotlin.outputs

import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 * Weekly Schedule properties, make a snapshot every week at a specific day or days
 * @property day Indicates which weekdays snapshot should be taken, accepts a comma separated list of week day names in english
 * @property hour Indicates which hour in UTC timezone a snapshot should be taken
 * @property minute Indicates which minute snapshot should be taken
 * @property snapshotsToKeep Weekly snapshot count to keep
 * @property usedBytes Resource size in bytes, current storage usage for the volume in bytes
 */
public data class WeeklyScheduleResponse(
    public val day: String? = null,
    public val hour: Int? = null,
    public val minute: Int? = null,
    public val snapshotsToKeep: Int? = null,
    public val usedBytes: Double? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.netapp.outputs.WeeklyScheduleResponse): WeeklyScheduleResponse = WeeklyScheduleResponse(
            day = javaType.day().map({ args0 -> args0 }).orElse(null),
            hour = javaType.hour().map({ args0 -> args0 }).orElse(null),
            minute = javaType.minute().map({ args0 -> args0 }).orElse(null),
            snapshotsToKeep = javaType.snapshotsToKeep().map({ args0 -> args0 }).orElse(null),
            usedBytes = javaType.usedBytes().map({ args0 -> args0 }).orElse(null),
        )
    }
}
